// BasicTalker.java

package uk.org.redfelineninja.awt;

import java.awt.*;
import java.awt.event.*;
import java.io.Writer;

import javax.swing.*;

/**
 * The BasicTalker provides a simple talker interface. Since it extends from
 * JPanel it can be added to any application or frame that requires chat
 * functions.
 */
public class BasicTalker extends JPanel {
    JTextAreaWriter writer;
    JTextArea textArea;
    JTextField textField;

    public BasicTalker() {
        super(new BorderLayout());

        // text area work
        textArea = new JTextArea();
        textArea.setBackground(this.getBackground());
        textArea.setLineWrap(true);
        JScrollPane textScroller =
            new JScrollPane(textArea, JScrollPane.VERTICAL_SCROLLBAR_ALWAYS, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);

        this.add(textScroller, BorderLayout.CENTER);
        writer = new JTextAreaWriter(textArea, textScroller);

        // text field work
        textField = new JTextField("");
        this.add(textField, BorderLayout.SOUTH);

        textField.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                fireActionListener(e);
            }
        });
    } // BasicTalker()

    /**
     * Get a writer to send text to the main text area.
    
     * @return Writer linked to the main text area.
     */
    public Writer getWriter() {
        return writer;
    }

    /**
     * Get the text from the talker.
     *
     * @return the String in the text entry field.
     */
    public String getText() {
        return textField.getText();
    }

    /**
     * Set the text in the text entry field.
     */
    public void setText(String text) {
        textField.setText(text);
    }

    /**
     * Add a listener to the talker. The talker will fire an ActionEvent
     * whenever the user presses return in the text field.
     */
    public void addActionListener(ActionListener a) {
        listenerList.add(ActionListener.class, a);
    }

    /**
     * Remove a listener from this talker.
     */
    public void removeActionListener(ActionListener a) {
        listenerList.remove(ActionListener.class, a);
    }

    protected void fireActionListener(ActionEvent e) {
        // guaranteed to return non-null
        Object[] listeners = listenerList.getListenerList();

        ActionEvent actionEvent = null;

        // process first to last
        for (int i = listeners.length - 2; i >= 0; i -= 2) {
            if (listeners[i] == ActionListener.class) {
                if (actionEvent == null)
                    actionEvent = new ActionEvent(this, ActionEvent.ACTION_PERFORMED, e.getActionCommand(), e.getModifiers());

                // send the event
                 ((ActionListener) listeners[i + 1]).actionPerformed(actionEvent);
            } // if (fired event)
        } // for
    } // fireActionEvent( ActionEvent )

    /**
     * Force the talker to take a new background colour.
     */
    public void setBackground(Color c) {
        super.setBackground(c);
        if (textArea != null)
            textArea.setBackground(c);
    }

} // BasicTalker
