// ColorBlockIcon.java

package uk.org.redfelineninja.awt;

import java.awt.*;

import javax.swing.Icon;

/**
 * This icon is a single block of colour.
 *
 * This class could be used to provide a coloured button that will call a
 * colour selector.
 * @author Daniel Thompson, Jan 1999
 */
public class ColorBlockIcon implements Icon {
    // DATA MEMBERS

    Color color;
    Dimension size;
    boolean autoSize;

    // CONSTUCTORS

    public ColorBlockIcon() {
        this(Color.red);
    }

    public ColorBlockIcon(Color c) {
        color = c;
        autoSize = true;
    }

    public ColorBlockIcon(Color c, Dimension s) {
        color = c;
        size = s;
        autoSize = false;
    }

    // GET and SET METHODS

    /**
     * Set whether this icon should automatically resize to its environment.
     */
    public void setAutoSize(boolean a) {
        autoSize = a;
    }

    /**
     * Detect whether this Icon will automatically resize to its environment.
     *
     * @return true if the Icon will automatically resize.
     */
    public boolean getAutoSize() {
        return autoSize;
    }

    /**
     * Set the size of the icon. This is ignored if the Icon can automatically
     * resize.
     */
    public void setSize(Dimension s) {
        size = s;
    }

    /**
     * Returns the current size of this Icon.
     */
    public Dimension getSize() {
        return size;
    }

    public Color getColor() {
        return color;
    }

    public void setColor(Color c) {
        color = c;
    }

    // NEEDED TO BE AN Icon

    /**
     * Get the height of the icon.
     *
     * If the icon can automatically resize this method will return 10 to prevent
     * problems during screen resize. Otherwise it returns the specified size.
     *
     * @return the height of the icon
     */
    public int getIconHeight() {
        return (autoSize ? 10 : size.height);
    }

    /**
     * Get the width of the icon.
     *
     * If the icon can automatically resize this method will return 10 to prevent
     * problems during screen resize. Otherwise it returns the specified size.
     *
     * @return the width of the icon
     */
    public int getIconWidth() {
        return (autoSize ? 10 : size.width);
    }

    public void paintIcon(Component c, Graphics g, int x, int y) {
        if (autoSize) {
            size = c.getSize();
        }

        g.setColor(this.color);
        g.fillRect(x, y, size.width, size.height);
    } // paintIcon( Component, Graphics, int, int )
} // ColorBlockIcon.class
