// ImageMap.java

package uk.org.redfelineninja.awt;

import uk.org.redfelineninja.image.*;

import java.awt.*;
import java.awt.event.*;
import java.util.*;

/**
 * The ImageMap allows programmers to rapidly detect mouse clicks on a image
 * based on the colour that was clicked on.
 * <p>
 * It extends from PixMap and provides all the drawing funtions of that class.
 * @see uk.ac.warwick.starfish.awt.PixMap
 */
public class ImageMap extends PixMap {
    PixMap originalPixMap;

    /**
     * This hashtable maps colours (RBG Integer) to lables (Object).
     */
    protected Hashtable colorTable;

    /**
     * This hashtable maps labels (Object) to centres of land mass (Point).
     */
    protected Hashtable seedTable;

    public ImageMap(Image img) {
        super(img);
        originalPixMap = new PixMap(img);

        seedTable = new Hashtable();
        colorTable = new Hashtable();

        addMouseListener(new MouseHandler());
    }

    /**
     * All keys relating to non points are removed from the Hashtable
     */
    public ImageMap(Image img, Hashtable zones) {
        super(img);
        originalPixMap = new PixMap(img);

        seedTable = zones;
        buildColorTable();

        addMouseListener(new MouseHandler());
    }

    protected void buildColorTable() {
        colorTable = new Hashtable(seedTable.size());

        Enumeration labels = seedTable.keys();
        Enumeration seeds = seedTable.elements();

        while (seeds.hasMoreElements()) {
            try {
                Point p = (Point) seeds.nextElement();
                colorTable.put(new Integer(originalPixMap.getPixel(p)), labels.nextElement());
            } catch (ClassCastException e) {
                seedTable.remove(labels.nextElement());
                System.err.println("Removed invalid data from seedTable");
            }
        }
    } // buildColorTable()

    /**
     * Paint a zone a particular colour.
     */
    public void paintZone(Object zone) {
        // after initialisation seedTable can only contain Points
        Point point = (Point) seedTable.get(zone);

        floodFill(point.x, point.y);
    } // paintZone( Object, Color )

    public Color getCountryColor(Object country) {
        return null;
    }

    public Color getOriginalCountryColor(Object country) {
        return null;
    }

    // EVENT HANDLING AND CREATION

    Vector actionListenerList = new Vector();

    /**
     * adds an ActionListener to the button
     */
    public void addActionListener(ActionListener l) {
        actionListenerList.addElement(l);
    }

    /**
     * removes an ActionListener from the button
     */
    public void removeActionListener(ActionListener l) {
        actionListenerList.removeElement(l);
    }

    String actionCommand = "no zone";

    protected String getActionCommand() {
        return actionCommand;
    }

    protected void fireActionPerformed(ActionEvent event) {
        Enumeration e = actionListenerList.elements();

        if (e.hasMoreElements()) {
            String actionCommand = event.getActionCommand();
            if (actionCommand == null) {
                actionCommand = getActionCommand();
            } // if
            ActionEvent ae = new ActionEvent(this, ActionEvent.ACTION_PERFORMED, actionCommand, event.getModifiers());
            while (e.hasMoreElements()) {
                ((ActionListener) e.nextElement()).actionPerformed(ae);
            } // while
        } // if
    } // fireActionPerformed( ActionEvent event )

    class MouseHandler extends MouseAdapter {
        public void mouseClicked(MouseEvent e) {
            // get pixel from original image
            try {
                Integer color = new Integer(originalPixMap.getPixel(e.getX(), e.getY()));

                if (colorTable.containsKey(color)) {
                    fireActionPerformed(
                        new ActionEvent(this, ActionEvent.ACTION_PERFORMED, colorTable.get(color).toString(), e.getModifiers()));
                } // if
            } catch (ArrayIndexOutOfBoundsException ae) {
                // clicked off the image, do nothing
            }
        }
    }

    public String toString() {
        StringBuffer sb = new StringBuffer();

        sb.append("ImageMap ").append(hashCode()).append("\n");
        sb.append("Seedtable\n");
        sb.append(seedTable).append("\n");
        sb.append("Colortable\n");
        sb.append(colorTable);

        return sb.toString();
    } // toString()
} // class
