// GraphicsToolkit.java

package uk.org.redfelineninja.image;

import java.awt.*;

/**
 * This is a utility class to draw useful things onto a graphics context.
 *
 * Ideally this should be achieved through sub-classing Graphics as
 * BufferedReader sub-classes Reader. However things could well get
 * very messy that way so this is a static utility class.
 *
 * @see java.awt.Graphics
 * @author Daniel Thompson, Dec 98/Jan 1999
 */
public class GraphicsToolkit {

    /**
     * Center a string at the supplied point.
     */
    public static void centerString(Graphics g, String s, int x, int y) {
        FontMetrics fm = g.getFontMetrics();
        y = y + fm.getHeight() / 2;
        x = x - fm.stringWidth(s) / 2;

        g.drawString(s, x, y);
    }

    /**
     * Center a string at the supplied point inside a box with a white
     * background.
     */
    public static Rectangle centerBoxedString(Graphics g, String s, int x, int y) {
        int w, h;

        FontMetrics fm = g.getFontMetrics();
        w = fm.stringWidth(s);
        h = fm.getHeight();

        Color paintColor = g.getColor();
        g.setColor(Color.white);

        // intuition sucks, y - h/2 + 1 ought to be -1 but that broke things.
        Rectangle r = new Rectangle(x - w / 2 - 1, y - h / 2 + 1, w + 2, h + 2);
        g.fillRect(r.x, r.y, r.width, r.height);
        g.setColor(paintColor);
        g.drawRect(r.x, r.y, r.width, r.height);
        g.drawString(s, x - w / 2, y + h / 2);

        return r;
    }
} // GraphicsToolkit.class
