// GenericMulticaster.java

package uk.org.redfelineninja.net;

import java.lang.reflect.InvocationTargetException;

/**
 * This class provides a means for classes that can not inherit from
 * AbstractMulticaster to make use of its services. This is achieved by
 * making the invokeMethod method publically accessable.
 * <P>
 * This is considerable potential for this to be abused. This is why it in not
 * included in the AbstractMulticaster. Take care.
 * <P>
 * For an example of acceptable use please refer to MulticastWriter.java from
 * the same package as this class.
 *
 * @see AbstractMulticaster
 * @see MulticastWriter
 */
public class GenericMulticaster extends AbstractMulticaster {
    /**
     * See super class
     */
    public final Object[] invokeMethod(String name, Object[] args) {
        return super.invokeMethod(name, args);
    }
} // GenericMulticaster.class
