// RiskClientFrame.java

package uk.org.redfelineninja.risk.client;

import uk.org.redfelineninja.risk.client.*;
import uk.org.redfelineninja.risk.io.MapDefinition;
import uk.org.redfelineninja.risk.robot.SimpleRobot;
import uk.org.redfelineninja.awt.*;

import java.awt.*;
import java.awt.event.*;
import java.beans.*;
import java.io.*;
import java.net.*;

import javax.swing.*;
import javax.swing.border.*;

/**
 * This is the main container frame for the Risk Client application and
 * applet.
 *
 * @version 0.1 28/12/98
 * @author Daniel Thompson
 */
public class RiskClientFrame extends JFrame {
    // DATA MEMBERS THAT MUST BE MAINTAINED
    BasicTalker talker;
    RiskMap map;
    RiskStatusBar statusBar;
    RiskTurnBar turnBar;
    RiskClient parent;

    JMenuBar menuBar;

    // CONTRUCTOR

    public RiskClientFrame(RiskClient p) {
        super("The Risk Arena");

        parent = p;

        buildMenus();
        buildContent();

        // close cleanly
        this.addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                quit();
            }

            public void windowClosed(WindowEvent e) {
                System.exit(1);
            }
        }); // addWindowListener
    } // contructor()

    // ACCESSORS
    public BasicTalker getTalker() {
        return talker;
    }
    public RiskMap getRiskMap() {
        return map;
    }
    public RiskStatusBar getStatusBar() {
        return statusBar;
    }
    public RiskTurnBar getTurnBar() {
        return turnBar;
    }

    // ACTIONS

    public void newGame() {
        RiskNetworkDialog dialog = new RiskNetworkDialog(this, true);

        dialog.addActionListener(new RiskNetworkDialogListener(parent.getServer()));
        dialog.setVisible(true);

    }

    public void joinGame() {
        RiskNetworkDialog dialog = new RiskNetworkDialog(this, false);

        dialog.addActionListener(new RiskNetworkDialogListener(parent.getServer()));
        dialog.setVisible(true);
    }

    public void watchGame() {}
    public void addPlayer() {}
    public void addRobot() {
        String[] args = new String[1];
        args[0] = "--noblock";
        SimpleRobot.main(args);
    }

    public void startGame() {
        parent.getServer().startGame();
    }

    public void quit() {
        int choice = JOptionPane.showConfirmDialog(this, Words.quitPrompt, Words.Are_You_Sure, JOptionPane.YES_NO_OPTION);

        if (choice == JOptionPane.YES_OPTION) {
            try {
                parent.getServer().closeConnection();
            } catch (IOException e) {
                // what else can we do?
                e.printStackTrace();
            }
            System.exit(0);
        }
    } // quit()

    protected void doShowCards(boolean b) {
        parent.getCardFrame().setVisible(b);
    }

    protected void doShowTalker(boolean b) {
        parent.getTalkerFrame().setVisible(b);
    }

    // CONTENT

    private void buildContent() {
        try {
            MapDefinition mapDef = new MapDefinition(new File("maps/risk.map"));
            Image img = Toolkit.getDefaultToolkit().getImage(mapDef.getImageFile().toString());

            map = new RiskMap(img, mapDef.getSeeds());
        } catch (FileNotFoundException e) {
            JOptionPane.showMessageDialog(null, Words.mapNotFound, Words.error, JOptionPane.INFORMATION_MESSAGE);
        }

        JPanel main = new JPanel();
        main.setLayout(new BorderLayout());

        main.add(new JScrollPane(map), BorderLayout.CENTER);
        map.addActionListener(new RiskMapListener(parent.getServer()));

        // put the name of the country into the status bar (clears out debris)
        map.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                statusBar.setStatus(e.getActionCommand());
            }
        });

        // status bar setup
        statusBar = new RiskStatusBar();
        main.add(statusBar, BorderLayout.SOUTH);

        turnBar = new RiskTurnBar(null, parent.getServer());
        main.add(new JScrollPane(turnBar), BorderLayout.WEST);

        getContentPane().add(main);
        pack();
    } // buildContents()

    // MENU CONTRUCTION, this is boring and very repetative, action is higher up

    protected void buildMenus() {
        menuBar = new JMenuBar();
        menuBar.setOpaque(true);

        // add menus
        menuBar.add(buildRiskMenu());
        menuBar.add(buildEditMenu());
        menuBar.add(buildGameMenu());
        menuBar.add(buildViewMenu());
        menuBar.add(buildHelpMenu());

        // add the menubar in
        setJMenuBar(menuBar);
    } // buildMenus()

    protected JMenu buildRiskMenu() {
        JMenu risk = new JMenu(Words.Risk);

        // menu items
        JMenuItem newGame = new JMenuItem(Words.New_Game);
        JMenuItem joinGame = new JMenuItem(Words.Join_Game);
        JMenuItem watchGame = new JMenuItem(Words.Watch_Game);
        JMenuItem addPlayer = new JMenuItem(Words.Add_Player);
        JMenuItem addRobot = new JMenuItem(Words.Add_Robot);
        JMenuItem quit = new JMenuItem(Words.Quit);

        // disable those actions that have not been writen
        watchGame.setEnabled(false);
        addPlayer.setEnabled(false);

        // wire up actions

        newGame.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                newGame();
            }
        });

        joinGame.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                joinGame();
            }
        });

        watchGame.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                watchGame();
            }
        });

        addPlayer.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                addPlayer();
            }
        });

        addRobot.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                addRobot();
            }
        });

        quit.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                quit();
            }
        });

        // add the menu items
        risk.add(newGame);
        risk.add(joinGame);
        risk.add(watchGame);
        risk.addSeparator();
        risk.add(addPlayer);
        risk.add(addRobot);
        risk.addSeparator();
        risk.add(quit);

        return risk;
    } // buildRiskMenu()

    protected JMenu buildEditMenu() {
        JMenu edit = new JMenu(Words.Edit);

        // menu items
        JMenuItem undo = new JMenuItem(Words.Undo);
        JMenuItem cut = new JMenuItem(Words.Cut);
        JMenuItem copy = new JMenuItem(Words.Copy);
        JMenuItem paste = new JMenuItem(Words.Paste);
        JMenuItem clear = new JMenuItem(Words.Clear);

        undo.setEnabled(false);
        cut.setEnabled(false);
        copy.setEnabled(false);
        paste.setEnabled(false);
        clear.setEnabled(false);

        edit.add(undo);
        edit.addSeparator();
        edit.add(cut);
        edit.add(copy);
        edit.add(paste);
        edit.add(clear);

        return edit;
    } // buildEditMenu()

    protected JMenu buildGameMenu() {
        JMenu game = new JMenu(Words.Game);

        // menu items
        JMenuItem start = new JMenuItem(Words.Start);
        JMenuItem fortify = new JMenuItem(Words.Fortify);
        JMenuItem done = new JMenuItem(Words.Done);
        JMenuItem stats = new JMenuItem(Words.Statistics + "...");

        start.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                startGame();
            }
        });
        ActionListener listener = new RiskGameMenuListener(parent.getServer());

        fortify.addActionListener(listener);
        done.addActionListener(listener);

        stats.setEnabled(false);

        game.add(start);
        game.addSeparator();
        game.add(fortify);
        game.add(done);
        game.addSeparator();
        game.add(stats);

        return game;
    } // buildGameMenu()

    protected JMenu buildViewMenu() {
        JMenu view = new JMenu(Words.View);

        // menu items
        JCheckBoxMenuItem dice = new JCheckBoxMenuItem(Words.Show_Dice, false);
        JCheckBoxMenuItem talker = new JCheckBoxMenuItem(Words.Show_Talker, false);
        JCheckBoxMenuItem cards = new JCheckBoxMenuItem(Words.Show_Cards, false);
        JCheckBoxMenuItem dock_talker = new JCheckBoxMenuItem(Words.Dock_Talker, true);

        dice.setEnabled(false);
        dock_talker.setEnabled(false);

        talker.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                // call doShowTalker with the Checkbox's state.
                doShowTalker(((JCheckBoxMenuItem) e.getSource()).getState());
            }
        });

        cards.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                // call doShowCards with the Checkbox's state.
                doShowCards(((JCheckBoxMenuItem) e.getSource()).getState());
            }
        });

        view.add(dice);
        view.add(talker);
        view.add(cards);
        view.addSeparator();
        view.add(dock_talker);

        return view;
    } // buildViewMenu()

    private JMenu buildHelpMenu() {
        JMenu help = new JMenu(Words.Help);

        // menu items
        JMenuItem about = new JMenuItem(Words.About);
        JMenuItem manual = new JMenuItem(Words.User_Manual);
        JMenuItem home_page = new JMenuItem(Words.Home_Page);

        ActionListener listener = new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                try {
                    if (e.getActionCommand().toString().equals(Words.About)) {
                        new HtmlFrame(new File("docs/about.html"), "About Risk");
                    } else if (e.getActionCommand().toString().equals(Words.User_Manual)) {
                        new HtmlFrame(new File("docs/client/user.html"), "User Manual");
                    } else if (e.getActionCommand().toString().equals(Words.Home_Page)) {
                        new HtmlFrame(
                            new URL("http://www.redfelineninja.dsl.pipex.com/software.html"),
                            "The Risk Arena");
                    }
                } catch (MalformedURLException mue) {
                    // this is impossible
                    mue.printStackTrace();
                } catch (Exception ex) {
                    JOptionPane.showMessageDialog(null, "No on-line help is available", "Sorry", JOptionPane.INFORMATION_MESSAGE);
                }
            }
        }; // ActionListener.class

        about.addActionListener(listener);
        manual.addActionListener(listener);
        home_page.addActionListener(listener);

        help.add(about);
        help.addSeparator();
        help.add(manual);
        help.add(home_page);

        return help;
    } // buildHelpMenu()
} // RiskClientFrame.class
