// RiskMap.java

package uk.org.redfelineninja.risk.client;

import uk.org.redfelineninja.image.GraphicsToolkit;
import uk.org.redfelineninja.awt.ImageMap;
import java.awt.*;
import java.util.*;

/**
 * This class provides all the tools required to display any Risk map. It
 * extends from ImageMap and therefore has all the abilities to detect mouse
 * clicks and paint territories. It also displays a number associated with each
 * country and can show selection graphically.
 */
public class RiskMap extends ImageMap {
    private Hashtable armies;
    private Object selection;

    /**
     * Hardcoded contructor to play <quote>classic</quote> Risk. This expects
     * to be given the standard Risk arena map.
     * <p>
     * This contructor is not used by any Risk Arena components. It remains
     * becasue there is still some test code that uses the code here.
     *
     * @deprecated This is dead code and <strong>should not be used</strong>
     */
    public RiskMap(Image img) {
        super(img);

        Hashtable t = new Hashtable();
        t.put("Alaska", new Point(40, 69));
        t.put("Northwest Teritory", new Point(115, 67));
        t.put("Greenland", new Point(285, 52));
        t.put("Alberta", new Point(92, 112));
        t.put("Ontario", new Point(165, 126));
        t.put("Quebec", new Point(231, 130));
        t.put("Western United States", new Point(94, 158));
        t.put("Eastern United States", new Point(169, 171));
        t.put("Central America", new Point(90, 212));
        t.put("Venezuela", new Point(123, 256));
        t.put("Peru", new Point(106, 305));
        t.put("Brazil", new Point(165, 312));
        t.put("Argentina", new Point(103, 370));
        t.put("Iceland", new Point(296, 114));
        t.put("Scandinavia", new Point(326, 138));
        t.put("Ukraine", new Point(377, 156));
        t.put("Great Britain", new Point(284, 180));
        t.put("Northern Europe", new Point(312, 190));
        t.put("Western Europe", new Point(288, 212));
        t.put("Southern Europe", new Point(328, 213));
        t.put("North Africa", new Point(280, 266));
        t.put("Eygpt", new Point(332, 251));
        t.put("East Africa", new Point(357, 285));
        t.put("Congo", new Point(321, 300));
        t.put("South Africa", new Point(331, 334));
        t.put("Madagascar", new Point(385, 340));
        t.put("Ural", new Point(446, 115));
        t.put("Siberia", new Point(500, 111));
        t.put("Yakutsk", new Point(552, 85));
        t.put("Irkutsk", new Point(524, 136));
        t.put("Kamchatka", new Point(584, 118));
        t.put("Afganistan", new Point(426, 187));
        t.put("China", new Point(492, 199));
        t.put("Mongolia", new Point(523, 180));
        t.put("Japan", new Point(581, 190));
        t.put("Middle East", new Point(382, 234));
        t.put("India", new Point(446, 236));
        t.put("Siam", new Point(500, 238));
        t.put("Indonesia", new Point(528, 279));
        t.put("New Guinea", new Point(592, 284));
        t.put("Western Australia", new Point(549, 325));
        t.put("Eastern Australia", new Point(592, 317));

        seedTable = t;

        buildColorTable();

        armies = new Hashtable();
    } // RiskMap

    /**
     * Create a new image map using the supplied list of zones.
     */
    public RiskMap(Image img, Hashtable zones) {
        super(img, zones);

        armies = new Hashtable();
    } // RiskMap( Image, Hashtable )

    /**
     * Set the number of armies in the supplied country. The supplied country
     * must exist.
     */
    public void setArmies(Object country, int value) {
        if (value <= 0) {
            armies.remove(country);
        } else {
            armies.put(country, new Integer(value));
        }

        // this may hurt but it makes coding more pleasent
        repaint();
    }

    /**
     * Get the number of armies in the supplied country. The supplied country
     * exist.
     */
    public int getArmies(Object country) {
        Integer a = (Integer) armies.get(country);
        if (a == null) {
            return 0;
        }

        return a.intValue();
    }

    /**
     * Set the selection to the supplied country. The supplied country must
     * exist.
     */
    public void setSelection(Object country) {
        selection = country;

        // this may hurt but it makes things more pleasent to code
        repaint();
    }

    /**
     * Get the currently selected country.
     */
    public Object getSelection() {
        // this is usually an immutable string
        return selection;
    }

    /**
     * Paint as the super class and draw in the number of armies in each country
     * and the selection.
     */
    public void paint(Graphics g) {
        super.paint(g);

        Point p;
        Integer value;
        Enumeration countries = armies.keys();
        Enumeration values = armies.elements();

        while (countries.hasMoreElements()) {
            value = (Integer) values.nextElement();
            p = (Point) seedTable.get(countries.nextElement());
            GraphicsToolkit.centerBoxedString(g, value.toString(), p.x, p.y);
        } // while

        // draw in the selected country
        if (selection != null) {
            p = (Point) seedTable.get(selection);
            GraphicsToolkit.centerBoxedString(g, selection.toString(), p.x, p.y + 20);
        }
    } // paint( Graphics )
} // RiskMap
