// RiskStatus.java

package uk.org.redfelineninja.risk.client;

import uk.org.redfelineninja.image.*;

import java.awt.*;

import javax.swing.*;
import javax.swing.border.*;

/**
 * The RiskStatusBar is a component that serves two purposes, displaying a 
 * status message and displaying a number of armies.
 */
public class RiskStatusBar extends JComponent {
    public static final String status = "status";

    // number of armies to be shown
    int armies;
    int fifties, tens, fives, units;

    // all images must be the same size
    Dimension imageSize;
    String statusText;

    // this is the minimum number of units that must be displayed
    final static short minUnits = 3;

    /**
     * Default constructor, creates a status bar with no armies in it.
     */
    public RiskStatusBar() {
        this(0);
    }

    public RiskStatusBar(int a) {
        super();

        setArmies(a);

        // this.setBackground( Color.white );
        this.setForeground(Color.black);
        imageSize = new Dimension(32, 32);
        statusText = Words.The_Risk_Arena;

        this.setBorder(new EtchedBorder());
    }

    public Dimension getMininumSize() {
        return new Dimension(imageSize.width * 12, imageSize.height);
    }

    public Dimension getPreferredSize() {
        return new Dimension(imageSize.width * 15, imageSize.height);
    }

    public Dimension getMaximumSize() {
        return new Dimension(9999, imageSize.height + 2);
    }

    public void setArmies(int a) {
        armies = a;

        if (a > (minUnits + 5)) {
            // we must garantee some units
            a -= minUnits;

            fifties = a / 50;

            a = a % 50;
            tens = a / 10;

            a = a % 10;
            fives = a / 5;

            a = a % 5;
            units = a + minUnits;
        } else {
            fifties = tens = fives = 0;
            units = a;
        } // if

        // must repaint
        repaint();
    } // setArmies( int )

    public int getArmies() {
        return armies;
    }

    public String getStatus() {
        return statusText;
    }

    public void setStatus(String s) {
        statusText = s;

        // must repaint
        repaint();
    }

    public void paintComponent(Graphics g) {
        // set the background and draw around my borders
        g.setColor(getBackground());
        g.fillRect(0, 0, getSize().width, getSize().height);
        g.setColor(getForeground());
        // g.drawRect( 0, 0, getSize().width-1, getSize().height-1 );

        // draw the status message
        FontMetrics fm = g.getFontMetrics();
        int x = getSize().width - fm.stringWidth(statusText) - 5;
        int y = (getSize().height + fm.getHeight() - 1) / 2;

        g.drawString(statusText, x, y);

        // draw in the armies (currently as text)
        int i, x_pos = 0;
        int halfWidth = imageSize.width / 2;
        int halfHeight = imageSize.height / 2;

        for (i = 0; i < fifties; i++) {
            GraphicsToolkit.centerBoxedString(g, "50", x_pos + halfWidth, halfHeight);
            x_pos += imageSize.width;
        }

        for (i = 0; i < tens; i++) {
            GraphicsToolkit.centerBoxedString(g, "10", x_pos + halfWidth, halfHeight);
            x_pos += imageSize.width;
        }

        for (i = 0; i < fives; i++) {
            GraphicsToolkit.centerBoxedString(g, "5", x_pos + halfWidth, halfHeight);
            x_pos += imageSize.width;
        }

        for (i = 0; i < units; i++) {
            GraphicsToolkit.centerBoxedString(g, "1", x_pos + halfWidth, halfHeight);
            x_pos += imageSize.width;
        }

    } // paint( Graphics )
} // RiskStatus.class
