// RiskTurnBar.java

package uk.org.redfelineninja.risk.client;

import uk.org.redfelineninja.risk.data.Player;
import uk.org.redfelineninja.risk.net.RiskServerInterface;

import uk.org.redfelineninja.awt.*;
import java.awt.*;
import java.awt.event.ActionListener;
import javax.swing.*;

/**
 * The RiskTurnBar is a component to display which player has to play next.
 */
public class RiskTurnBar extends JPanel {
    private Player[] players;
    private JButton[] buttons;
    private Box buttonBox;

    private Color unselected;
    private Color selected;

    /**
     * Create a new RiskTurnBar without any players in it.
     */
    public RiskTurnBar(RiskServerInterface server) {
        this(null, server);
    }

    /**
     * Create a new RiskTurnBar using the listed player.
     *
     * @param p list of players that are to be displayed on this turn bar. null
     * legal.
     * 
     */
    public RiskTurnBar(Player[] p, RiskServerInterface server) {
        super();

        setLayout(new BorderLayout());

        buttonBox = Box.createVerticalBox();

        // add the components to the bar
        add(buttonBox, BorderLayout.CENTER);
        add(buildTurnButtons(server), BorderLayout.SOUTH);

        // register the players
        setPlayers(p);

    } // RiskTurnBar( Color [] )

    /**
     * Define the players that are taking part in the current game.
     */
    public void setPlayers(Player[] p) {
        // empty the button box
        buttonBox.removeAll();

        // register the players
        players = p;

        // if there are not any players then return
        if (p == null) {
            return;
        }

        buttons = new JButton[p.length];

        Dimension d = new Dimension(48, 32);
        // add the players to the box
        for (int i = 0; i < p.length; i++) {
            ColorBlockIcon icon = new ColorBlockIcon(players[i].color, d);
            buttons[i] = new JButton(icon);

            buttons[i].setToolTipText(players[i].name);

            buttonBox.add(buttons[i]);
        }

        // set the colors
        unselected = buttons[0].getBackground();
        selected = unselected.darker();

        // cause repaint
        buttonBox.invalidate();
        validate();
    } // setPlayers( Player [] )

    /**
     * Tell the turn bar to move to this player.
     */
    public void turn(Player p) {
        // if there is nothing on the bar then do nothing
        if (players == null) {
            return;
        }

        // set button background accordingly
        for (int i = 0; i < players.length; i++) {
            buttons[i].setBackground((players[i].equals(p) ? selected : unselected));
        } // for( i )

        // force a repaint
        buttonBox.invalidate();
        validate();
    } // turn( Player )

    protected JPanel buildTurnButtons(RiskServerInterface server) {
        JPanel turn = new JPanel();
        turn.setLayout(new ColumnLayout());

        JButton fortify = new JButton(Words.Fortify);
        JButton done = new JButton(Words.Done);

        ActionListener listener = new RiskGameMenuListener(server);

        fortify.addActionListener(listener);
        done.addActionListener(listener);

        turn.add(fortify);
        turn.add(done);

        return turn;
    } // buildTurnButtons()
} // RiskTurnBar.class
