// Continent.java

package uk.org.redfelineninja.risk.data;

import java.util.*;

/**
 * Data type representing a Continent.
 */
public class Continent {
    // data members
    public final String name;
    public final int value;
    private StringVector countriesP;

    /**
     * Create a new continent. 
     * <p> No two different continents should have the same
     * name, see the equals method.
     */
    public Continent(String n, int v) {
        name = n;
        value = v;

        countriesP = new StringVector();
    }

    /**
     * Compare two continents for equality. This method makes the assumption that
     * continents are uniquely identified by their name. Bearing this in mind
     * remember that this method may give incorrect matches it a continent does
     * not have a unique name.
     */
    public boolean equals(Object obj) {
        // are we comparing like with like
        if (obj instanceof Continent) {
            return ((Continent) obj).name.equals(this.name);
        } else {
            return false;
        }
    } // equals( Object )

    /**
     * Add a country to this continent.
     */
    public boolean addCountry(String c) {
        if (countriesP.contains(c)) {
            return false;
        } else {
            countriesP.addElement(c);
            return true;
        }
    }

    /**
     * Provides a list of the countries contained within this continent.
     */
    public Enumeration countries() {
        return countriesP.elements();
    }
} // Continent.class
