// ContinentVector.java

package uk.org.redfelineninja.risk.data;

/**
 * This class provides alternative fetch methods on a Vector that have Continent
 * return types and perform type safety operations. Objects that are not
 * Continents should not really be added to this Vector.
 *
 * @author Daniel Thompson, Feb 1999
 */
public class ContinentVector extends java.util.Vector {
    /**
     * Returns the component at the specified index as a String.
     */
    public final Continent continentAt(int index) {
        if (elementData[index] instanceof Continent) {
            return (Continent) elementData[index];
        } else {
            return null;
        }
    } // continentAt( int )

    /**
     * Copies the compenents of this vector to the specified array of Continents.
     * The array must be large enough to contains all the elements of this
     * Vector.
     */
    public final void copyInto(Continent[] array) {
        for (int i = 0; i < elementCount; i++) {
            if (elementData[i] instanceof Continent) {
                array[i] = (Continent) elementData[i];
            } else {
                array[i] = null;
            }
        } // for
    } // copyInto( Continent [] )
} // ContinentVector.class
