// RiskServerDebug.java

package uk.org.redfelineninja.risk.test;

import uk.org.redfelineninja.risk.data.*;
import uk.org.redfelineninja.risk.net.*;
import uk.org.redfelineninja.awt.*;

import java.awt.*;
import java.awt.event.*;
import java.io.*;

import javax.swing.*;

public class RiskServerDebug extends JFrame implements RiskServerInterface {
    Writer writer;
    RiskClientInterface client = null;

    public RiskServerDebug() {
        super("Server Debugging info");

        BasicTalker talker = new BasicTalker();
        writer = talker.getWriter();

        talker.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                doSend(((BasicTalker) e.getSource()).getText());
            }
        });

        getContentPane().add(talker);

        this.setSize(480, 200);
        this.setVisible(true);
    }

    protected void doSend(String cmd) {
        if (client != null) {
            client.message(cmd);
        } else {
            try {
                writer.write("No known client\n");
                writer.flush();
            } catch (IOException e) {
                e.printStackTrace();
            }
        } // if

    }

    boolean connected = false;

    public void openConnection(String hostname, int port, Player player) {
        try {
            writer.write("openConnection( " + hostname + ", " + port + " ," + player + " )\n");
            writer.flush();
        } catch (IOException e) {
            e.printStackTrace();
        }
        connected = true;
    }

    public void closeConnection() {
        try {
            writer.write("closeConnection()\n");
            writer.flush();
        } catch (IOException e) {
            e.printStackTrace();
        }
        connected = false;
    }

    public boolean isConnected() {
        try {
            writer.write("isConnected()\n");
            writer.flush();
        } catch (IOException e) {
            e.printStackTrace();
        }
        return connected;
    }

    public void newGame(String gamename, boolean random, boolean privacy) {
        try {
            writer.write("newGame( " + gamename + ", " + random + ", " + privacy + " )\n");
            writer.flush();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void joinGame(String gamename) {
        try {
            writer.write("joinGame( " + gamename + " )\n");
            writer.flush();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void leaveGame() {
        try {
            writer.write("leaveGame()\n");
            writer.flush();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void startGame() {
        try {
            writer.write("startGame()\n");
            writer.flush();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void stopGame(String reason) {
        try {
            writer.write("stopGame( " + reason + " )\n");
            writer.flush();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void message(String message) {
        try {
            writer.write("message( " + message + " )\n");
            writer.flush();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void message(String message, Player player) {
        try {
            writer.write("message( " + message + ", " + player + " )\n");
            writer.flush();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void countryClicked(String country) {
        try {
            writer.write("countryClicked( " + country + " )\n");
            writer.flush();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void cards(Card[] cards) {
        try {
            writer.write("cards( " + cards + " )\n");
            writer.flush();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void fortify() {
        try {
            writer.write("fortify()\n");
            writer.flush();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void finishTurn() {
        try {
            writer.write("finishTurn()\n");
            writer.flush();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
} // RiskServerDebug.class
