// RiskTestServer.java

package uk.org.redfelineninja.risk.test;

import java.net.*;
import java.io.*;

/**
 * This class provides a means to test a clients network layer. It accepts
 * multiple connections on the supplied port and echos anything sent to the
 * server back to all connected clients. This allows the netowrk layer of the
 * client to be tested using the clients own talker.
 */
public class RiskTestServer {
    private int port;

    public RiskTestServer() {
        this(2005);
    }

    public RiskTestServer(int p) {
        port = p;

        // large trys are nasty but we don't need to be robust
        try {
            ServerSocket server = new ServerSocket(port);

            System.out.println("RiskTestServer started on port " + port);

            while (true) {
                Socket connection = server.accept();
                new ServerSession(connection).start();

                System.out.println("Accepted connection from " + connection.getInetAddress().getHostName());
            } // while( true )
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public static void main(String args[]) {
        broadcast.addWriter(new OutputStreamWriter(System.out));
        new RiskTestServer();
    }

    private static BroadcastWriter broadcast = new BroadcastWriter();

    protected class ServerSession extends Thread {
        private Socket connection;
        private BufferedReader in;
        private BufferedWriter out;

        public ServerSession(Socket c) {
            connection = c;

            try {
                // set up the streams
                in = new BufferedReader(new InputStreamReader(connection.getInputStream()));
                out = new BufferedWriter(new OutputStreamWriter(connection.getOutputStream()));
            } catch (IOException e) {
                e.printStackTrace();
                System.exit(1);
            }

            broadcast.addWriter(out);
        }

        // the session
        public void run() {
            String cmd = "null";
            try {

                // the work starts here
                while (0 != cmd.compareTo("exit")) {
                    cmd = in.readLine();

                    try {
                        if (0 == cmd.compareTo("exit")) {
                            broadcast.write("-- " + connection.getInetAddress().getHostName() + " logged out\n");
                            broadcast.flush();
                        } else if (-1 == cmd.indexOf("message( ")) {
                            broadcast.write(cmd + "\n");
                            broadcast.flush();
                        } else {
                            // chop off "message( " the hacky way
                            broadcast.write(cmd.substring(9, cmd.length() - 2) + '\n');
                            broadcast.flush();
                        }
                    } catch (IOException ioe) {
                        System.err.println("One or more connections are out of date");
                    } catch (NullPointerException e) {
                        // leave gracefully
                        cmd = "exit";
                    }
                }

                System.out.println("Closing connection");
                broadcast.removeWriter(out);

                connection.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        } // run
    } // ServerSession.class
} // class
